/*
	$Id: rtconfig.h 421 2005-07-28 13:32:33Z crosser $
*/

/*
	WHAT IS IT:
		modularized contentfilter for Zmailer
	COPYRIGHT:
		(c) 2003-2005 Eugene G. Crosser <crosser@average.org>
	LICENSE:
		The same set as apply to Zmailer code
*/

#ifndef RTCONFIG_H
#define RTCONFIG_H

typedef struct _gcfg {
	int firstmimehdr;
	int maxsize;
	char *socket;
	char *initstage;
	char *finalstage;
	char *pidfile;
	char *modconfdir;
	char *miltersock;
	char *myfqdn;
	char *mydomain;
} gcfg_t;
extern gcfg_t gcfg;

extern int
readconfig(char *fn,int loadmodules);
extern void
init_dyn_modules(void);

#endif
